@@ -1,14 +1,16 @@
-from typing import Any, Dict
+from typing import Dict, Union
+
+from datasets import Split
 
 from .builder import GeneratorBasedBuilder
 from .dataset import Dataset
 from .dataset_formatter import DocumentFormatter
 
-Metadata = Dict[str, Any]
+DatasetDict = Dict[Union[str, Split], Dataset]
 
 __all__ = [
-    "Metadata",
     "GeneratorBasedBuilder",
     "Dataset",
+    "DatasetDict",
     "DocumentFormatter",
 ]
